==> core-1.0-sources.jar: one/xingyi/core/httpClient/client/view/UrlPatternDebugInfo.java <==
package one.xingyi.core.httpClient.client.view;
//Made by one.xingyi.core.filemaker.ViewDomDebugFileMaker
//Defn one.xingyi.core.httpClient.IUrlPatternDefn
import java.lang.String;
public class UrlPatternDebugInfo {
/*
Deprecated: false
Original: one.xingyi.core.httpClient.IUrlPatternDefn
    Entity:     one.xingyi.core.httpClient.client.entitydefn.IUrlPatternClientEntity
    View:        one.xingyi.core.httpClient.client.view.UrlPattern
    Impl   :    one.xingyi.core.httpClient.client.view.UrlPatternImpl
    ServerImpl: one.xingyi.core.httpClient.client.viewcompanion.UrlPatternCompanion
    Original: one.xingyi.core.httpClient.IResourceDetailsDefn
        IServer:    one.xingyi.core.httpClient.server.domain.IResourceDetails
        ServerImpl: one.xingyi.core.httpClient.server.domain.ResourceDetails
        Client:     one.xingyi.core.httpClient.client.entitydefn.IResourceDetailsClientEntity
        ServComp:   one.xingyi.core.httpClient.server.companion.ResourceDetailsCompanion
        Lens:       ResourceDetails
Fields: 1
    Field: urlPattern
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  lens path for views not done yet
        Lens name  lens for views not done yet
        Readonly   false
        Javascript functionlensforviewsnotdoneyet(){returnlens('urlPattern');};
        Templated: false
        Deprecated false

Deprecated: false
Original: one.xingyi.core.httpClient.IResourceDetailsDefn
    IServer:    one.xingyi.core.httpClient.server.domain.IResourceDetails
    ServerImpl: one.xingyi.core.httpClient.server.domain.ResourceDetails
    Client:     one.xingyi.core.httpClient.client.entitydefn.IResourceDetailsClientEntity
    ServComp:   one.xingyi.core.httpClient.server.companion.ResourceDetailsCompanion
    Lens:       ResourceDetails
bookmarkAndUrl Optional[BookmarkCodeAndUrlPattern(bookmark=/resource, urlPattern={host}/{id}, code={host}/resource/code)]
Fields: 1
    Field: urlPattern
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  urlPattern/String
        Lens name  lens_ResourceDetails_urlPattern
        Readonly   false
        Javascript functionlens_ResourceDetails_urlPattern(){returnlens('urlPattern');};
        Templated: true
        Deprecated false
Get            Optional[GetDom()]
optionalGet    Optional[OptionalGetDom()]
Put            Optional.empty
Create         Optional.empty
CreateNoId     Optional.empty
Delete         Optional.empty
prototype:     Optional.empty
prototypeNoId: Optional.empty
Posts:         []
*/}

==> core-1.1-sources.jar: one/xingyi/core/httpClient/client/view/UrlPatternDebugInfo.java <==
package one.xingyi.core.httpClient.client.view;
//Made by one.xingyi.core.filemaker.ViewDomDebugFileMaker
//Defn one.xingyi.core.httpClient.IUrlPatternDefn
import java.lang.String;
public class UrlPatternDebugInfo {
/*
Deprecated: false
Original: one.xingyi.core.httpClient.IUrlPatternDefn
    Entity:     one.xingyi.core.httpClient.client.entitydefn.IUrlPatternClientEntity
    View:        one.xingyi.core.httpClient.client.view.UrlPattern
    Impl   :    one.xingyi.core.httpClient.client.view.UrlPatternImpl
    ServerImpl: one.xingyi.core.httpClient.client.viewcompanion.UrlPatternCompanion
    Original: one.xingyi.core.httpClient.IResourceDetailsDefn
        IServer:    one.xingyi.core.httpClient.server.domain.IResourceDetails
        ServerImpl: one.xingyi.core.httpClient.server.domain.ResourceDetails
        Client:     one.xingyi.core.httpClient.client.entitydefn.IResourceDetailsClientEntity
        ServComp:   one.xingyi.core.httpClient.server.companion.ResourceDetailsCompanion
        Lens:       ResourceDetails
Fields: 1
    Field: urlPattern
        StringPrimitiveType()
        Lens path  lens path for views not done yet
        Lens name  lens for views not done yet
        Readonly   false
        Javascript functionlensforviewsnotdoneyet(){returnlens('urlPattern');};
        Templated: false
        Deprecated false

Deprecated: false
Original: one.xingyi.core.httpClient.IResourceDetailsDefn
    IServer:    one.xingyi.core.httpClient.server.domain.IResourceDetails
    ServerImpl: one.xingyi.core.httpClient.server.domain.ResourceDetails
    Client:     one.xingyi.core.httpClient.client.entitydefn.IResourceDetailsClientEntity
    ServComp:   one.xingyi.core.httpClient.server.companion.ResourceDetailsCompanion
    Lens:       ResourceDetails
bookmarkAndUrl Optional[BookmarkCodeAndUrlPattern(bookmark=/resource, urlPattern={host}/{id}, code={host}/resource/code)]
Fields: 1
    Field: urlPattern
        StringPrimitiveType()
        Lens path  urlPattern/String
        Lens name  lens_ResourceDetails_urlPattern
        Readonly   false
        Javascript functionlens_ResourceDetails_urlPattern(){returnlens('urlPattern');};
        Templated: true
        Deprecated false
Get            Optional[GetDom()]
optionalGet    Optional[OptionalGetDom()]
Put            Optional.empty
Create         Optional.empty
CreateNoId     Optional.empty
Delete         Optional.empty
prototype:     Optional.empty
prototypeNoId: Optional.empty
Posts:         []
*/}
